{% load markup %}
{{ block.description|markdown }}

{% if request.user.is_anonymous %}
  <p class="warning">You must be logged in to view this content</p>
{% else %}

{% for question in block.question_set.all %}
  {% include 'likertblock/question.html' %}
{% endfor %}


{% endif %}
