{% load markup %}
{% load likertgetresponse %}

{% getquestionresponse question as response %}

<div class="form-group">
  <h4>{{question.text|markdown}}</h4>

	<label class="radio-inline">
		<input type="radio" id=""
					 value="0"
					 {% ifequal response.value 0 %}
					 checked="checked"
					 {% endifequal %}
					 name="pageblock-{{block.pageblock.id}}-likert-question{{question.id}}"> Strongly Disagree
	</label>

	<label class="radio-inline">
		<input type="radio" id=""
					 value="1"
					 {% ifequal response.value 1 %}
					 checked="checked"
					 {% endifequal %}
					 name="pageblock-{{block.pageblock.id}}-likert-question{{question.id}}"> Somewhat Disagree
	</label>

	<label class="radio-inline">
		<input type="radio" id=""
					 value="2"
					 {% if response.value == 2 or response.value == None %}
					 checked="checked"
					 {% endif %}
					 name="pageblock-{{block.pageblock.id}}-likert-question{{question.id}}"> Neutral
	</label>

	<label class="radio-inline">
		<input type="radio" id="" value="4"
					 {% ifequal response.value 4 %}
					 checked="checked"
					 {% endifequal %}
 name="pageblock-{{block.pageblock.id}}-likert-question{{question.id}}"> Somewhat Agree
	</label>

	<label class="radio-inline">
		<input type="radio" id="" value="5"
					 {% ifequal response.value 5 %}
					 checked="checked"
					 {% endifequal %}
 name="pageblock-{{block.pageblock.id}}-likert-question{{question.id}}"> Strongly Agree
	</label>


</div>


